/* *****************************************************************************
;                                                                             *
;    Filename:                     				                              *
;    Date:                                         	                          *
;    File Version: 001                                                        *
;                                                                             *
;    Author:   Jason Lopez                                                    *
;    Company:  AtomSoft                                                       *
;                                                                             *
;***************************************************************************** */

#include <p18f2525.h>
#include <delays.h>
#include <string.h>
#include "lcd.h"
#include "i2c.h"
//#include <i2c.h>

#pragma config WDT = OFF, LVP = OFF, OSC = INTIO67, XINST = OFF

/************************************
Prototypes
*************************************/
void main(void);
void WriteLM75(unsigned char Address, unsigned char Data);
signed int ReadLM75BD(void);

void InitLM(void);
signed int ReadLM(void);
/************************************
Variables and Defines
*************************************/

    signed int tH;
    signed int tT;
    signed int tO;


void main(void){
	signed int temp;

	OSCCON = 0x72;      			//8MHz clock
    while(!OSCCONbits.IOFS);		//wait for osc stable

    ADCON1 = 0x0F;
    LCD_Init();

    DelayMS(3);
    LCD_LINE(1);
    LCD_STR((unsigned rom char*)"  AtomSoftTech  ");

while(1){

    LCD_LINE(2);
    LCD_STR((unsigned rom char*)"Temp: ");

    temp = 0;
    temp=ReadLM75BD();      //get temperature
    if(temp<0){             //if negative
        LCD_DATA('-',1);    //put minus sign
        temp=-temp;         //and negate temperature
    } else {                //else
        LCD_DATA(' ',1);    //put a space
    }

  
    temp*=9;
    temp/=5;
    temp+=64;

    tH = ((temp/2) / 100) + 0x30;
    tT = (((temp/2) % 100) / 10) + 0x30;
    tO = ((temp/2) % 10) + 0x30;

    LCD_DATA(tH,1);
    LCD_DATA(tT,1);
    LCD_DATA(tO,1);

    LCD_DATA('.',1);        //put decimal point
    if(temp&1)              //if there was a half degree
         LCD_DATA('5',1);   //display it
    else
         LCD_DATA('0',1);    //or dont

     LCD_DATA('F',1);    //or dont

    DelayMS(250);
    DelayMS(250);
    DelayMS(250);
    DelayMS(250);
}

}

signed int ReadLM75BD(void){
signed int tmpR;

    i2c_Start(); //Send Start
    i2c_write(RAdd); //Send our Device Address with the Write BIT

    i2c_Ack(); //Test for ACK

    tmpR = i2c_read(); //Read 1 Byte from device and save in tmp
    i2c_Ack(); //Test for ACK

    tmpR = tmpR << 8;
    tmpR |= i2c_read(); //Read 1 Byte from device and save in tmp

    i2c_NAck(); //Test for NACK
    i2c_Stop(); //Send Stop

    tmpR = tmpR >> 7;
    return tmpR;
}


