#include "lcd.h"
unsigned char BF;
//--------------------------------------------------------------------------------//
void LCD_Init(void){
    #if ENDIAN==LOWER           //This will check if ENDIAN is LOW and if so
        BF = LOWEND;            //Set the BusyFlag MASK to check lower nibble
    #else                       //if not LOW, but HIGH(UPPER) then
        BF = UPPEND;            //Set BF to check upper nibble
    #endif

    #if ENDIAN==LOWER
        LCD_TRIS &= UPPMSK;       //ensure lower nibble is output
    #else
        LCD_TRIS &= LOWMSK;       //ensure upper nibble is output
    #endif

    LCD_E=0;                    //clear enable
    LCD_RS = 0;                 //going to write command
    LCD_TRIS_E=0;               //Set enable to output
    LCD_TRIS_RS=0;              //set RS to output
    #ifdef LCD_RW
        LCD_TRIS_RW=0;
        LCD_RW=0;
    #endif
    DelayMS(30);                //delay for LCD to initialise.
    LCD_NYB(0x30);              //Required for initialisation
    DelayMS(5);                 //required delay
    LCD_NYB(0x30);              //Required for initialisation
    DelayMS(1);                 //required delay
    LCD_DATA(0x02,0);           //set to 4 bit interface, 1 line and 5*7 font
    LCD_DATA(0x28,0);           //set to 4 bit interface, 2 line and 5*10 font
    LCD_DATA(0x0c,0);           //set to 4 bit interface, 2 line and 5*7 font
    LCD_DATA(0x01,0);           //clear display
    LCD_DATA(0x06,0);           //move cursor right after write

}
//--------------------------------------------------------------------------------//
void LCD_DATA(unsigned char data,unsigned char type){
    
    WaitLCDBusy();                  //TEST LCD FOR BUSY 

    if(type == CMD){
        LCD_RS = 0;                 //COMMAND MODE
    } else {
        LCD_RS = 1;                 //CHARACTER/DATA MODE
    }

    LCD_NYB(data>>4);               //WRITE THE UPPER NIBBLE
    LCD_NYB(data);                  //WRITE THE LOWER NIBBLE
}
//--------------------------------------------------------------------------------//
void WaitLCDBusy(void){
#ifdef LCD_RW                       //IF THE LCD_RW DEFINITION IS USED
    LCD_RS=0;                       //COMMAND MODE
    LCD_RW=1;                       //READ MODE

    #if ENDIAN==LOWER               //ENDIAN = 0? 
        LCD_TRIS |= LOWMSK;         //YES = SET LOWER NIBBLE INPUT
    #else                           //ELSE ENDIAN = 1
        LCD_TRIS |= UPPMSK;         //SET UPPER NIBBLE INPUT
    #endif

    LCD_E=1;                        //ENABLE LCD DATA LINES
    while(LCD_DAT & BF);            //TEST BUSY FLAG BIT
    LCD_E=0;                        //DISABLE LCD DATA LINES

    #if ENDIAN==LOWER               //ENDIAN = 0? 
        LCD_TRIS &= UPPMSK;         //YES = SET LOWER NIBBLE OUTPUT
    #else                           //ELSE ENDIAN = 1
        LCD_TRIS &= LOWMSK;         //SET UPPER NIBBLE OUTPUT
    #endif

    LCD_RW=0;
#else

    DelayMS(2);              //DELAY 1 MilliSeconds

#endif
}
//--------------------------------------------------------------------------------//
void LCD_NYB(unsigned char nyb){
    #if ENDIAN==LOWER                           //ENDIAN = 0? Yes Send the data LOWER
        LCD_PORT &= UPPMSK;                     //CLEAR LOWER PORT NIBBLE
        LCD_PORT |= (nyb & LOWMSK);             //SEND DATA LINE THE INFO 
    #else                                       //ENDIAN = 1 so send to HIGHER
        LCD_PORT &= LOWMSK;                     //CLEAR UPPER PORT NIBBLE
        LCD_PORT |= ((nyb << 4) & UPPMSK);      //SHIFT DATA OVER << 4, CLEAR LOWER NIBBLE
    #endif
    
    LCD_E = 1;          //ENABLE LCD DATA LINE
    Nop();              //SMALL DELAY
    LCD_E = 0;          //DISABLE LCD DATA LINE
}
//--------------------------------------------------------------------------------//
void LCD_STR(unsigned rom char *text){
    while(*text){
        LCD_DATA(*text++,1);
    }
}
//--------------------------------------------------------------------------------//
void LCD_STR2(unsigned char *text){
    while(*text){
        LCD_DATA(*text++,1);
    }
}
//--------------------------------------------------------------------------------//
void LCD_LINE(char line){
    switch(line){
        case 0:
        case 1:
            LCD_DATA(0x80,0);
            break;
        case 2:
            LCD_DATA(0xC0,0);
            break;
    }
}
//--------------------------------------------------------------------------------//
void ShiftDisplay(unsigned char DC,unsigned char RL){
    unsigned char shift=0x10;
    if(DC == DISPLAY)
        shift |= 0b00001000;

    if(RL == RIGHT)
        shift |= 0b00000100;

    LCD_DATA(shift,0);
}
//--------------------------------------------------------------------------------//
void DelayMS(unsigned int ms){
    unsigned int x;
    for(x=0;x<ms;x++)
        Delay1KTCYx(2);
}
//--------------------------------------------------------------------------------//
